# Contributors

## Maintainers
- Martin Fitzner (Merck KGaA, Darmstadt, Germany), [Contact](mailto:martin.fitzner@merckgroup.com), [Github](https://github.com/Scienfitz)
- Adrian Šošić (Merck Life Science KGaA, Darmstadt, Germany), [Contact](mailto:adrian.sosic@merckgroup.com), [Github](https://github.com/AdrianSosic)
- Alexander Hopp (Merck KGaA, Darmstadt, Germany), [Contact](mailto:alexander.hopp@merckgroup.com), [Github](https://github.com/AVHopp)

## Contributors
- Alex Lee (EMD Electronics, Tempe, Arizona, USA):\
  Work on surrogate models
- Daniel Weber (Merck KGaA, Darmstadt, Germany):\
  Telemetry prototype
- Emeline Sola (during an internship at Merck KGaA, Darmstadt, Germany):\
  Auto-documentation of the examples
- Sourabh Agrawal (Sigma-Aldrich Chemicals Private Limited):\
  Initial implementation of additional surrogate models and clustering methods
- Julie Fang (Merck Life Science KGaA, Darmstadt, Germany):\
  Farthest point sampling
- Roya Javadi (Vector Institute, Toronto, Canada):\
  Import optimization, Polars implementations
- Sterling Baird (Acceleration Consortium, Toronto, Canada):\
  Documentation and general feedback
- Rim Rihana (Merck KGaA, Darmstadt, Germany):\
  Human readable output for search spaces
- Di Jin (Merck Life Science KGaA, Darmstadt, Germany):\
  Cardinality constraints
- Julian Streibel (Merck Life Science KGaA, Darmstadt, Germany):\
  Bernoulli multi-armed bandit and Thompson sampling
- Karin Hrovatin (Merck KGaA, Darmstadt, Germany):\
  `scikit-fingerprints` support
- Fabian Liebig (Merck KGaA, Darmstadt, Germany):\
  Benchmarking structure and persistence capabilities for benchmarking results
- Alexander Wieczorek (Swiss Federal Institute for Materials Science and Technology, Dübendorf, Switzerland):\
  SHAP explainers for insights